@@ -17,11 +17,12 @@
 #' @references Tucker, J. D. 2014, Functional Component Analysis and Regression using Elastic Methods. Ph.D. Thesis, Florida State University.
 #' @references Robinson, D. T. 2012, Function Data Analysis and Partial Shape Matching in the Square Root Velocity Framework. Ph.D. Thesis, Florida State University.
 #' @references Huang, W. 2014, Optimization Algorithms on Riemannian Manifolds with Applications. Ph.D. Thesis, Florida State University.
+#' @references Srivastava, A., Klassen, E., Joshi, S., Jermyn, I., (2011). Shape analysis of elastic curves in euclidean spaces. Pattern Analysis and Machine Intelligence, IEEE Transactions on 33 (7), 1415-1428.
 #' @docType package
 #' @useDynLib fdasrvf
-#' @import foreach mvtnorm matrixcalc numDeriv splines parallel doParallel Rcpp
+#' @import foreach mvtnorm matrixcalc splines parallel doParallel Rcpp fields
 #' @importFrom graphics layout legend matplot plot title
-#' @importFrom stats approx cov optim predict quantile rnorm runif sd smooth.spline var
+#' @importFrom stats approx cov optim predict quantile rnorm runif sd smooth.spline var spline
 #' @aliases fdasrvf fdasrvf-package
 NULL
 #' Simulated two Gaussian Dataset
@@ -86,3 +87,15 @@ NULL
 #' @usage data("simu_warp")
 #' @format A list which contains the outputs of the time_warping function
 NULL
+#' MPEG7 Curve Dataset
+#'
+#' Contains the MPEG7 curve data set which is 20 curves in 65 classes. The array
+#' is structured with dimension (2,100,65,20)
+#'
+#'
+#' @docType data
+#' @keywords datasets
+#' @name beta
+#' @usage data("mpeg7")
+#' @format an array of shape (2,100,65,20)
+NULL
